#
# spec file for package python-atpublic
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-atpublic
Version:        5.0
Release:        1.1
Summary:        @public decorator for populating __all__
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            http://public.readthedocs.io/
Source:         https://gitlab.com/warsaw/public/-/archive/%{version}/public-%{version}.tar.gz#/atpublic-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module hatch}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
# SECTION test requirements
BuildRequires:  %{python_module atpublic}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sybil}
# /SECTION
%endif
%python_subpackages

%description
public -- @public for populating __all__.

%prep
%setup -q -n public-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%else

%check
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc docs/NEWS.rst README.rst
%license LICENSE
%{python_sitelib}/public
%{python_sitelib}/atpublic-%{version}*-info
%endif

%changelog
* Thu Aug 22 2024 Frantisek Simorda <frantisek.simorda@suse.com>
- Update to 5.0:
  * @public is now properly type annotated.
  * Adopt hatch test and hatch fmt commands. (GL#25)
  * @public and @private now raise TypeError instead of ValueError if __all__ is not a concrete list object. (GL#26)
  * Other minor coding improvements identified by ruff.
  * Switch to Trusted Publishing for publishing new versions to PyPI. (GL#24)
- version 4.1:
  * Add support for Python 3.12. (GL#22)
  * Switch to hatch, replacing pdm and tox. (GL#21)
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- remove obsolete pdm-pep517 dependency
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0:
  * Drop Python 3.7 support (GL#16)
  * Remove ``public.install()`` which was used to inject the
    ``public`` and ``private`` functions into the ``builtins``
    namespace.  This isn't very helpful and could be actively
    harmful.  Explicit is better than implicit. (GL#14)
  * The functional form of ``public()`` now returns the argument
  * values* in the order they are given.  This allows you to
    explicitly bind those values to names in the global namespace.
  * Switch from ``flake8`` and ``isort`` to ``ruff`` for code
    quality. (GL#32)
  * Switch to ``pdm-backend`` (GL#15)
  * More GitLab CI integration improvements.
* Tue Jun 13 2023 Dirk Müller <dmueller@suse.com>
- tag for sle15 new python stack
* Fri Mar 24 2023 Daniel Garcia <daniel.garcia@suse.com>
- Remove typing_extensions requirement not needed for python version > 3.8
* Sun Dec  4 2022 Torsten Gruner <simmphonie@opensuse.org>
- Update to v3.1.1
  * Improvements to the GitLab CI integration.
- version 3.1 (2022-08-27)
  * Fix a typo in pyproject.toml file.
  * Exclude certain local cache files from the sdist/wheel.
  * Add support for Python 3.11.
  * Updates for pdm and dependencies.
- version 3.0.1 (2022-01-10)
  * Fix a typo in the README.rst.
- version 3.0 (2022-01-10)
  * Use modern package management by adopting pdm and pyproject.toml, and dropping setup.py and setup.cfg.
  * Build the docs with Python 3.8.
  * Update to version 3.0 of Sybil.
  * Adopt the Furo documentation theme.
  * Use importlib.metadata.version() as a better way to get the package version number for the documentation.
  * Drop Python 3.6 support.
  * Update Windows GitLab runner to include Python 3.10.
  * Update copyright years.
  * The master branch is renamed to main. (GL#11)
* Tue Jan 11 2022 Ben Greiner <code@bnavigator.de>
- Fix sybil usage in conftest based on sybil version.
  * https://gitlab.com/warsaw/public/-/merge_requests/16
* Fri May 21 2021 pgajdos@suse.com
- version update to 2.3
  2.3 (2021-04-13)
  ================
  * Do type hinting the right way. (GL#10)
  2.2 (2021-04-13)
  ================
  * ``public()`` and ``private()`` can't be correctly type annotated, so the
    type hints on these two functions have been removed.  The ``ModuleAware``
    was also removed.  (GL#10)
  * Added a ``py.typed`` file to satisfy type checkers.  (GL#9)
  * Fixed a documentation cross-reference bug.
* Mon Nov 30 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2.1.1
  * Clean up some typing problems
  * Reorganized docs and tests out of the code directory
  * Fix the Windows CI tests
- from v2.0
  * Drop Python 3.4 and 3.5; add Python 3.8 and 3.9.
  * The C implementation is removed
  * Added an ``@private`` decorator
  * Build and test on Windows in addition to Linux
  * Fix the doctests so that they actually run and pass!
  * Add type annotations and API reference documentation
  * Internal improvements and modernizations
* Fri May 10 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.0
